@@ -85,12 +85,12 @@ expr_anova_parametric <- function(data,
                                   x,
                                   y,
                                   paired = FALSE,
+                                  k = 2L,
+                                  conf.level = 0.95,
                                   effsize.type = "unbiased",
                                   partial = TRUE,
-                                  conf.level = 0.95,
                                   var.equal = FALSE,
                                   sphericity.correction = TRUE,
-                                  k = 2L,
                                   stat.title = NULL,
                                   ...) {
 
@@ -98,8 +98,7 @@ expr_anova_parametric <- function(data,
   c(x, y) %<-% c(rlang::ensym(x), rlang::ensym(y))
 
   # for paired designs, variance is going to be equal across grouping levels
-  if (isTRUE(paired)) var.equal <- TRUE
-  if (isFALSE(paired)) sphericity.correction <- FALSE
+  if (isTRUE(paired)) var.equal <- TRUE else sphericity.correction <- FALSE
 
   # determine number of decimal places for both degrees of freedom
   k.df1 <- ifelse(isTRUE(paired) && isTRUE(sphericity.correction), k, 0L)
@@ -170,14 +169,8 @@ expr_anova_parametric <- function(data,
     ez_df <-
       rlang::eval_tidy(rlang::expr(
         ez::ezANOVA(
-          data =
-            data %>%
-              dplyr::mutate_if(
-                .tbl = .,
-                .predicate = is.character,
-                .funs = as.factor
-              ) %>%
-              dplyr::mutate(.data = ., rowid = as.factor(rowid)),
+          data = dplyr::mutate_if(.tbl = data, .predicate = is.character, .funs = as.factor) %>%
+            dplyr::mutate(.data = ., rowid = as.factor(rowid)),
           dv = !!rlang::ensym(y),
           wid = rowid,
           within = !!rlang::ensym(x),
@@ -230,11 +223,7 @@ expr_anova_parametric <- function(data,
     # tidy up the stats object
     stats_df <-
       suppressMessages(broomExtra::tidy(stats_obj)) %>%
-      dplyr::rename(
-        .data = .,
-        parameter1 = dplyr::matches("^num"),
-        parameter2 = dplyr::matches("^den")
-      )
+      dplyr::rename(parameter1 = dplyr::matches("^num"), parameter2 = dplyr::matches("^den"))
 
     # creating a standardized dataframe with effect size and its CIs
     effsize_object <-
@@ -263,10 +252,8 @@ expr_anova_parametric <- function(data,
       ci = conf.level
     ) %>%
     broomExtra::easystats_to_tidy_names(.) %>%
-    # renaming to standard term 'estimate'
-    dplyr::rename(.data = ., estimate = dplyr::matches("eta|omega")) %>%
-    dplyr::filter(.data = ., !is.na(estimate)) %>%
-    dplyr::filter(.data = ., !grepl(pattern = "Residuals", x = term, ignore.case = TRUE))
+    dplyr::rename(estimate = dplyr::matches("eta|omega")) %>%
+    dplyr::filter(!is.na(estimate), !grepl(pattern = "Residuals", x = term, ignore.case = TRUE))
 
   # test details
   statistic.text <-
@@ -354,9 +341,9 @@ expr_anova_nonparametric <- function(data,
                                      x,
                                      y,
                                      paired = FALSE,
-                                     conf.type = "perc",
-                                     conf.level = 0.95,
                                      k = 2L,
+                                     conf.level = 0.95,
+                                     conf.type = "perc",
                                      nboot = 100L,
                                      stat.title = NULL,
                                      ...) {
@@ -526,10 +513,10 @@ expr_anova_robust <- function(data,
                               x,
                               y,
                               paired = FALSE,
-                              tr = 0.1,
-                              nboot = 100,
-                              conf.level = 0.95,
                               k = 2L,
+                              conf.level = 0.95,
+                              tr = 0.1,
+                              nboot = 100L,
                               stat.title = NULL,
                               ...) {
 
