@@ -32,7 +32,7 @@ testthat::test_that(
           ", ",
           italic("p"),
           " = ",
-          "< 0.001",
+          "2.1714e-08",
           ", ",
           widehat(epsilon^2),
           " = ",
@@ -139,7 +139,7 @@ testthat::test_that(
           ", ",
           italic("p"),
           " = ",
-          "< 0.001",
+          "4.558e-12",
           ", ",
           widehat(italic("W"))["Kendall"],
           " = ",
@@ -188,7 +188,7 @@ testthat::test_that(
           ", ",
           italic("p"),
           " = ",
-          "< 0.001",
+          "1.51e-88",
           ", ",
           widehat(italic("W"))["Kendall"],
           " = ",
