@@ -425,7 +425,7 @@ testthat::test_that(
           ", ",
           italic("p"),
           " = ",
-          "< 0.001",
+          "1.32e-69",
           ", ",
           widehat(omega["p"]^2),
           " = ",
@@ -675,7 +675,7 @@ testthat::test_that(
         ", ",
         italic("p"),
         " = ",
-        "< 0.001",
+        "1.08e-11",
         ", ",
         widehat(omega["p"]^2),
         " = ",
