@@ -28,7 +28,7 @@ testthat::test_that(
           ", ",
           italic("p"),
           " = ",
-          "< 0.001",
+          "3.4438e-06",
           ", ",
           widehat(italic(rho))["Spearman"],
           " = ",
@@ -69,7 +69,7 @@ testthat::test_that(
           ", ",
           italic("p"),
           " = ",
-          "< 0.001",
+          "1.49e-11",
           ", ",
           widehat(italic(rho))["Spearman"],
           " = ",
@@ -115,7 +115,7 @@ testthat::test_that(
       ggplot2::expr(
         paste(
           NULL,
-          italic("t"),
+          italic("t")["Student"],
           "(",
           "46",
           ") = ",
@@ -170,24 +170,24 @@ testthat::test_that(
       ggplot2::expr(
         paste(
           NULL,
-          italic("t"),
+          italic("t")["Student"],
           "(",
           "54",
           ") = ",
-          "-5.0929",
+          "-5.3122",
           ", ",
           italic("p"),
           " = ",
-          "< 0.001",
+          "2.101e-06",
           ", ",
           widehat(italic(rho))["pb"],
           " = ",
-          "-0.5696",
+          "-0.5894",
           ", CI"["50%"],
           " [",
-          "-0.6289",
+          "-0.6466",
           ", ",
-          "-0.5037",
+          "-0.5257",
           "]",
           ", ",
           italic("n")["pairs"],
