@@ -38,7 +38,7 @@ testthat::test_that(
           ", ",
           italic("p"),
           " = ",
-          "< 0.001",
+          "6.0984e-24",
           ", ",
           widehat(italic("d"))["Cohen"],
           " = ",
@@ -101,7 +101,7 @@ testthat::test_that(
           ", ",
           italic("p"),
           " = ",
-          "< 0.001",
+          "5.8e-18",
           ", ",
           widehat(italic("g"))["Hedge"],
           " = ",
@@ -160,7 +160,7 @@ testthat::test_that(
           ", ",
           italic("p"),
           " = ",
-          "< 0.001",
+          "1.85e-73",
           ", ",
           widehat(italic("g"))["Hedge"],
           " = ",
@@ -216,7 +216,7 @@ testthat::test_that(
           ", ",
           italic("p"),
           " = ",
-          "< 0.001",
+          "5e-04",
           ", ",
           widehat(italic("d"))["Cohen"],
           " = ",
