@@ -30,7 +30,7 @@ testthat::test_that(
           ", ",
           italic("p"),
           " = ",
-          "< 0.001",
+          "0e+00",
           ", ",
           widehat(italic(delta))["R"],
           " = ",
@@ -140,7 +140,7 @@ testthat::test_that(
           ", ",
           italic("p"),
           " = ",
-          "< 0.001",
+          "1.97e-05",
           ", ",
           widehat(italic(xi)),
           " = ",
